@@ -5,7 +5,7 @@
 <context>
     <name>ProfileChangerWidget</name>
     <message>
-        <location filename="profilechangerwidget.ui" line="20"/>
+        <location filename="profilechangerwidget.ui" line="14"/>
         <source>ProfileChangerWidget</source>
         <translation>Profilwechsel Widget</translation>
     </message>
@@ -23,37 +23,62 @@
         <translation>Höhe</translation>
     </message>
     <message>
-        <location filename="settingsdialog.ui" line="52"/>
+        <location filename="settingsdialog.ui" line="55"/>
         <source>Width</source>
         <translation>Breite</translation>
     </message>
     <message>
-        <location filename="settingsdialog.cpp" line="12"/>
+        <location filename="settingsdialog.ui" line="75"/>
+        <source>Icon</source>
+        <translation>Symbol</translation>
+    </message>
+    <message>
+        <location filename="settingsdialog.ui" line="82"/>
+        <source>Next Profile</source>
+        <translation>Nächstes Profil</translation>
+    </message>
+    <message>
+        <location filename="settingsdialog.ui" line="92"/>
+        <source>Opacity</source>
+        <translation>Durchsichtigkeit</translation>
+    </message>
+    <message>
+        <location filename="settingsdialog.ui" line="115"/>
         <source>About</source>
         <translation>Über</translation>
     </message>
     <message>
-        <location filename="settingsdialog.cpp" line="27"/>
+        <location filename="settingsdialog.ui" line="122"/>
+        <source>Feedback</source>
+        <translation>Feedback</translation>
+    </message>
+    <message>
+        <location filename="settingsdialog.ui" line="129"/>
+        <source>Donate</source>
+        <translation>Schenken</translation>
+    </message>
+    <message>
+        <location filename="settingsdialog.cpp" line="28"/>
         <source>Fields cannot be empty!</source>
         <translation>Die Felder dürfen nicht leer sein!</translation>
     </message>
     <message>
-        <location filename="settingsdialog.cpp" line="40"/>
+        <location filename="settingsdialog.cpp" line="44"/>
         <source>About Profile Changer Widget</source>
         <translation>Über Profilwechsel Widget</translation>
     </message>
     <message>
-        <location filename="settingsdialog.cpp" line="43"/>
+        <location filename="settingsdialog.cpp" line="47"/>
         <source>Profile Changer Widget</source>
         <translation>Profilwechsel Widget</translation>
     </message>
     <message>
-        <location filename="settingsdialog.cpp" line="45"/>
+        <location filename="settingsdialog.cpp" line="49"/>
         <source>Small widget intended to enable an easy change between general and silent profiles.</source>
         <translation>Kleines Widget zum Wechseln des Profils zwischen Allgemein und Stumm.</translation>
     </message>
     <message>
-        <location filename="settingsdialog.cpp" line="47"/>
+        <location filename="settingsdialog.cpp" line="51"/>
         <source>Version:</source>
         <translation>Version:</translation>
     </message>
