@@ -11,10 +11,8 @@ SettingsDialog::SettingsDialog(QWidget *parent) :
     QSettings settings;
     ui->heightBox->setValue(settings.value("profilechangerwidget/height").toInt());
     ui->widthBox->setValue(settings.value("profilechangerwidget/width").toInt());
-    QPushButton *aboutButton = new QPushButton(tr("About"), this);
-    connect(aboutButton, SIGNAL(clicked()), this, SLOT(showAbout()));
-    connect(this, SIGNAL(rejected()), this, SLOT(close()));
-    ui->buttonBox->addButton(aboutButton, QDialogButtonBox::NoRole);
+    ui->spinBoxOpacity->setValue(settings.value("profilechangerwidget/opacity").toInt());
+    ui->checkBoxNextProfile->setChecked(settings.value("profilechangerwidget/showNextProfile").toBool());
 }
 
 SettingsDialog::~SettingsDialog()
@@ -26,12 +24,14 @@ void SettingsDialog::accept()
 {
     QSettings settings;
     if (ui->heightBox->text().isEmpty() || ui->widthBox->text().isEmpty()) {
-        QMaemo5InformationBox::information(this, tr("Fields cannot be empty!"));
+        this->showInformation(tr("Fields cannot be empty!"));
         return;
     }
 
     settings.setValue("profilechangerwidget/width", ui->widthBox->value());
     settings.setValue("profilechangerwidget/height", ui->heightBox->value());
+    settings.setValue("profilechangerwidget/opacity", ui->spinBoxOpacity->value());
+    settings.setValue("profilechangerwidget/showNextProfile", ui->checkBoxNextProfile->isChecked());
     emit settingsChanged();
     this->close();
 }
@@ -63,3 +63,58 @@ void SettingsDialog::showAbout()
     aboutDialog->show();
     this->close();
 }
+
+void SettingsDialog::on_buttonAbout_clicked()
+{
+    this->showAbout();
+}
+
+void SettingsDialog::on_buttonQa_clicked()
+{
+    this->openBrowser("http://maemo.org/packages/view/profile-changer-widget/");
+    this->close();
+}
+
+void SettingsDialog::on_buttonDonate_clicked()
+{
+    //TODO
+    //this->openBrowser("https://www.paypal.com/cgi-bin/webscr?cmd=_s-xclick&hosted_button_id=");
+    //this->close();
+    this->showInformation("ToDo");
+}
+
+void SettingsDialog::on_buttonBox_accepted()
+{
+    this->accept();
+}
+
+void SettingsDialog::on_buttonBox_rejected()
+{
+    this->close();
+}
+
+void SettingsDialog::openBrowser(QString url)
+{
+    QDBusMessage msg = QDBusMessage::createMethodCall(
+        "com.nokia.osso_browser", // --dest
+        "/com/nokia/osso_browser/request", // destination object path
+        "com.nokia.osso_browser", // message name (w/o method)
+        "load_url" // method
+    );
+    msg << url;
+    msg = QDBusConnection::systemBus().call(msg);
+
+}
+
+void SettingsDialog::showInformation(QString info)
+{
+    QDBusMessage msg = QDBusMessage::createMethodCall(
+        "org.freedesktop.Notifications", // --dest
+        "/org/freedesktop/Notifications", // destination object path
+        "org.freedesktop.Notifications", // message name (w/o method)
+        "SystemNoteInfoprint" // method
+    );
+    msg << info;
+    msg = QDBusConnection::sessionBus().call(msg);
+
+}
