@@ -3,8 +3,8 @@
 
 #include <QDialog>
 #include <QSettings>
-#include <QMaemo5InformationBox>
 #include <QPushButton>
+#include <QDBusInterface>
 
 namespace Ui {
     class SettingsDialog;
@@ -23,10 +23,17 @@ public:
 
 private:
     Ui::SettingsDialog *ui;
+    void openBrowser(QString url);
+    void showInformation(QString info);
 
 private slots:
     void accept();
     void showAbout();
+    void on_buttonAbout_clicked();
+    void on_buttonQa_clicked();
+    void on_buttonDonate_clicked();
+    void on_buttonBox_accepted();
+    void on_buttonBox_rejected();
 };
 
 #endif // SETTINGSDIALOG_H
